API documentation - autogenerated from docstrings
=================================================

Contents:

.. toctree::
   :maxdepth: 2

   directory.rst
   fields.rst
   filters.rst
   base.rst
   models.rst
   objectlist.rst
   resource.rst
   serialize.rst
